#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-mysql
version:              2.13.1.5
visibility:           public
id:                   persistent-mysql-2.13.1.5-HvawVz7vYVG6nlQaGAxub6
key:                  persistent-mysql-2.13.1.5-HvawVz7vYVG6nlQaGAxub6
license:              MIT
maintainer:           Felipe Lessa <felipe.lessa@gmail.com>
author:               Felipe Lessa <felipe.lessa@gmail.com>, Michael Snoyman
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:
    Backend for the persistent library using MySQL database server.

description:
    This package contains a backend for persistent using the
    MySQL database server.  Internally it uses the @mysql-simple@
    and @mysql@ packages in order to access the database.

    This package supports only MySQL 5.1 and above.  However, it
    has been tested only on MySQL 5.5.
    Only the InnoDB storage engine is officially supported.

    Known problems:

    * This package does not support statements inside other
    statements.

category:             Database, Yesod
abi:                  ed2449beec4481555ee817eb55a82191
exposed:              True
exposed-modules:      Database.Persist.MySQL
import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-mysql
hs-libraries:         HSpersistent-mysql-2.13.1.5-HvawVz7vYVG6nlQaGAxub6
depends:
    aeson-2.2.2.0-E8GnKqfyoqV8B1evVkUtMu base-4.18.2.1
    blaze-builder-0.4.4.1-Dw9P36L5aDQHwuD3TRuknC bytestring-0.11.5.3
    conduit-1.3.6.1-2TgBnHtxRcL45MnFdbw3BB containers-0.6.7
    monad-logger-0.3.42-GvKOwuNJXwdJj2TN1oDiNf
    mysql-0.2.1-5PhtRc0pFhQ4DWV6vA8BF2
    mysql-simple-0.4.9-9ttaU3QWGMvBHs5dBPqx0A
    persistent-2.14.5.2-3SKZjvJPM7iICTkzQZVMK9
    resource-pool-0.2.3.2-D1rxP2xu7M4IuTPF4aCDbG
    resourcet-1.2.6-1nkc80Rj0478ycxyUoAOs8 text-2.0.2
    transformers-0.6.1.0 unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-persistent-mysql/html/persistent-mysql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-mysql/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

